# !!!!!!!   DO NOT EDIT THIS FILE   !!!!!!!
# This file is machine-generated by lib/unicore/mktables from the Unicode
# database, Version 13.0.0.  Any changes made here will be lost!

# !!!!!!!   INTERNAL PERL USE ONLY   !!!!!!!
# This file is for internal use by core Perl only.  The format and even the
# name or existence of this file are subject to change without notice.  Don't
# use it directly.  Use Unicode::UCD to access the Unicode character data
# base.



# The name this table is to be known by, with the format of the mappings in
# the main body of the table, and what all code points missing from this file
# map to.
$Unicode::UCD::SwashInfo{'ToBpt'}{'format'} = 's'; # string
$Unicode::UCD::SwashInfo{'ToBpt'}{'missing'} = 'n';

return <<'END';
28		o
29		c
5B		o
5D		c
7B		o
7D		c
F3A		o
F3B		c
F3C		o
F3D		c
169B		o
169C		c
2045		o
2046		c
207D		o
207E		c
208D		o
208E		c
2308		o
2309		c
230A		o
230B		c
2329		o
232A		c
2768		o
2769		c
276A		o
276B		c
276C		o
276D		c
276E		o
276F		c
2770		o
2771		c
2772		o
2773		c
2774		o
2775		c
27C5		o
27C6		c
27E6		o
27E7		c
27E8		o
27E9		c
27EA		o
27EB		c
27EC		o
27ED		c
27EE		o
27EF		c
2983		o
2984		c
2985		o
2986		c
2987		o
2988		c
2989		o
298A		c
298B		o
298C		c
298D		o
298E		c
298F		o
2990		c
2991		o
2992		c
2993		o
2994		c
2995		o
2996		c
2997		o
2998		c
29D8		o
29D9		c
29DA		o
29DB		c
29FC		o
29FD		c
2E22		o
2E23		c
2E24		o
2E25		c
2E26		o
2E27		c
2E28		o
2E29		c
3008		o
3009		c
300A		o
300B		c
300C		o
300D		c
300E		o
300F		c
3010		o
3011		c
3014		o
3015		c
3016		o
3017		c
3018		o
3019		c
301A		o
301B		c
FE59		o
FE5A		c
FE5B		o
FE5C		c
FE5D		o
FE5E		c
FF08		o
FF09		c
FF3B		o
FF3D		c
FF5B		o
FF5D		c
FF5F		o
FF60		c
FF62		o
FF63		c
END
